@@ -3,8 +3,8 @@
 module Arel # :nodoc: all
   module Nodes
     class Count < Arel::Nodes::Function
-      def initialize(expr, distinct = false, aliaz = nil)
-        super(expr, aliaz)
+      def initialize(expr, distinct = false)
+        super(expr)
         @distinct = distinct
       end
     end
