@@ -5,8 +5,8 @@ module Arel # :nodoc: all
     class NamedFunction < Arel::Nodes::Function
       attr_accessor :name
 
-      def initialize(name, expr, aliaz = nil)
-        super(expr, aliaz)
+      def initialize(name, expr)
+        super(expr)
         @name = name
       end
 
