@@ -127,8 +127,7 @@ class LeftOuterJoinAssociationTest < ActiveRecord::TestCase
   def test_left_outer_joins_includes_all_nested_associations
     sql, = capture_sql { Friendship.left_outer_joins(:friend_favorite_reference_job, :follower_favorite_reference_job).to_a }
 
-    escape = -> name { Regexp.escape(Friendship.connection.quote_table_name(name)) }
-    assert_match %r(#{escape["friendships.friend_id"]}), sql
-    assert_match %r(#{escape["friendships.follower_id"]}), sql
+    assert_match %r(#{Regexp.escape(quote_table_name("friendships.friend_id"))}), sql
+    assert_match %r(#{Regexp.escape(quote_table_name("friendships.follower_id"))}), sql
   end
 end
