@@ -9,11 +9,12 @@ class ActiveRecord::Encryption::ConcurrencyTest < ActiveRecord::EncryptionTestCa
   end
 
   test "models can be encrypted and decrypted in different threads concurrently" do
-    4.times.collect { |index| thread_encrypting_and_decrypting("thread #{index}") }.each(&:join)
+    3.times.collect { |index| thread_encrypting_and_decrypting("thread #{index}") }.each(&:join)
   end
 
   def thread_encrypting_and_decrypting(thread_label)
-    posts = 200.times.collect { |index| EncryptedPost.create! title: "Article #{index} (#{thread_label})", body: "Body #{index} (#{thread_label})" }
+    EncryptedPost.insert_all 10.times.collect { |index| { title: "Article #{index} (#{thread_label})", body: "Body #{index} (#{thread_label})" } }
+    posts = EncryptedPost.last(10)
 
     Thread.new do
       posts.each.with_index do |article, index|
