@@ -1093,6 +1093,8 @@ class TransactionalFixturesOnConnectionNotification < ActiveRecord::TestCase
     end.new
 
     pool = connection.pool = Class.new do
+      attr_accessor :db_config
+
       def initialize(connection); @connection = connection; end
       def lease_connection; @connection; end
       def release_connection; end
@@ -1100,6 +1102,11 @@ class TransactionalFixturesOnConnectionNotification < ActiveRecord::TestCase
       def unpin_connection!; @connection.rollback_transaction; true; end
     end.new(connection)
 
+    connection.pool.db_config = Class.new do
+      attr_accessor :name
+      def initialize(name); @name = name; end
+    end.new("database_name")
+
     assert_called_with(pool, :pin_connection!, [true]) do
       fire_connection_notification(connection.pool)
     end
@@ -1120,6 +1127,8 @@ class TransactionalFixturesOnConnectionNotification < ActiveRecord::TestCase
     end.new
 
     connection.pool = Class.new do
+      attr_accessor :db_config
+
       def initialize(connection); @connection = connection; end
       def lease_connection; @connection; end
       def release_connection; end
@@ -1127,6 +1136,11 @@ class TransactionalFixturesOnConnectionNotification < ActiveRecord::TestCase
       def unpin_connection!; @connection.rollback_transaction; true; end
     end.new(connection)
 
+    connection.pool.db_config = Class.new do
+      attr_accessor :name
+      def initialize(name); @name = name; end
+    end.new("database_name")
+
     fire_connection_notification(connection.pool)
     teardown_fixtures
 
@@ -1144,6 +1158,8 @@ class TransactionalFixturesOnConnectionNotification < ActiveRecord::TestCase
     end.new
 
     connection.pool = Class.new do
+      attr_accessor :db_config
+
       def initialize(connection); @connection = connection; end
       def lease_connection; @connection; end
       def release_connection; end
@@ -1151,6 +1167,11 @@ class TransactionalFixturesOnConnectionNotification < ActiveRecord::TestCase
       def unpin_connection!; @connection.rollback_transaction; true; end
     end.new(connection)
 
+    connection.pool.db_config = Class.new do
+      attr_accessor :name
+      def initialize(name); @name = name; end
+    end.new("database_name")
+
     assert_called_with(connection.pool, :pin_connection!, [true]) do
       fire_connection_notification(connection.pool, shard: :shard_two)
     end
@@ -1446,7 +1467,7 @@ class FoxyFixturesTest < ActiveRecord::TestCase
 
   def test_only_generates_a_pk_if_necessary
     assert_nothing_raised do
-      m = Matey.first
+      m = Matey.take
       m.pirate = pirates(:blackbeard)
       m.target = pirates(:redbeard)
     end
