@@ -305,6 +305,33 @@ class OptimisticLockingTest < ActiveRecord::TestCase
     assert_equal ["lock_version", "updated_at"], t1.saved_changes.keys.sort
   end
 
+  def test_update_lock_version_to_nil_without_validation_or_constraint_raises_error
+    t1 = LockWithoutDefault.create!(title: "title1")
+    assert_raises(RuntimeError, match: locking_column_nil_error_message) { t1.update(lock_version: nil) }
+    assert_raises(RuntimeError, match: locking_column_nil_error_message) { t1.update!(lock_version: nil) }
+  end
+
+  def test_update_lock_version_to_nil_without_validation_raises
+    person = Person.find(1)
+    assert_raises(RuntimeError, match: locking_column_nil_error_message) { person.update(lock_version: nil) }
+    assert_raises(RuntimeError, match: locking_column_nil_error_message) { person.update!(lock_version: nil) }
+  end
+
+  def test_update_lock_version_to_nil_with_validation_does_not_raise_runtime_lock_version_error
+    person = LockVersionValidatedPerson.find(1)
+    assert_nothing_raised { person.update(lock_version: nil) }
+
+    assert_equal ["is not a number"], person.errors[:lock_version]
+  end
+
+  def test_update_bang_lock_version_to_nil_with_validation_does_not_raise_runtime_lock_version_error
+    error = assert_raises(ActiveRecord::RecordInvalid) do
+      LockVersionValidatedPerson.find(1).update!(lock_version: nil)
+    end
+
+    assert_equal ["is not a number"], error.record.errors[:lock_version]
+  end
+
   def test_touch_stale_object_with_lock_without_default
     t1 = LockWithoutDefault.create!(title: "title1")
     stale_object = LockWithoutDefault.find(t1.id)
@@ -557,6 +584,14 @@ class OptimisticLockingTest < ActiveRecord::TestCase
 
     assert_equal t1.attributes, t2.attributes
   end
+
+  private
+    def locking_column_nil_error_message
+      <<-MSG.squish
+        For optimistic locking, locking_column ('lock_version') can't be nil.
+        Are you missing a default value or validation on 'lock_version'?
+      MSG
+    end
 end
 
 class OptimisticLockingWithSchemaChangeTest < ActiveRecord::TestCase
@@ -821,3 +856,121 @@ class PessimisticLockingTest < ActiveRecord::TestCase
       end
   end
 end
+
+class PessimisticLockingWhilePreventingWritesTest < ActiveRecord::TestCase
+  CUSTOM_LOCK = if current_adapter?(:SQLite3Adapter)
+    "FOR UPDATE" # no-op
+  else
+    "FOR SHARE"
+  end
+
+  fixtures :people
+
+  def test_lock_when_not_preventing_writes
+    person = Person.last!
+    assert_nothing_raised do
+      person.lock!
+    end
+  end
+
+  def test_lock_when_preventing_writes
+    person = Person.last!
+    ActiveRecord::Base.while_preventing_writes do
+      assert_raises(ActiveRecord::ReadOnlyError) do
+        person.lock!
+      end
+    end
+  end
+
+  def test_lock_when_not_preventing_writes_nested
+    person = Person.last!
+    ActiveRecord::Base.while_preventing_writes do
+      ActiveRecord::Base.while_preventing_writes(false) do
+        assert_nothing_raised do
+          person.lock!
+        end
+      end
+    end
+  end
+
+  def test_custom_lock_when_preventing_writes
+    person = Person.last!
+    ActiveRecord::Base.while_preventing_writes do
+      assert_raises(ActiveRecord::ReadOnlyError) do
+        person.lock!(CUSTOM_LOCK)
+      end
+    end
+  end
+
+  def test_with_lock_when_not_preventing_writes
+    person = Person.last!
+    assert_nothing_raised do
+      person.with_lock do
+      end
+    end
+  end
+
+  def test_with_lock_when_preventing_writes
+    person = Person.last!
+    ActiveRecord::Base.while_preventing_writes do
+      assert_raises(ActiveRecord::ReadOnlyError) do
+        person.with_lock do
+        end
+      end
+    end
+  end
+
+  def test_with_lock_when_not_preventing_writes_nested
+    person = Person.last!
+    ActiveRecord::Base.while_preventing_writes do
+      ActiveRecord::Base.while_preventing_writes(false) do
+        assert_nothing_raised do
+          person.with_lock do
+          end
+        end
+      end
+    end
+  end
+
+  def test_custom_with_lock_when_preventing_writes
+    person = Person.last!
+    ActiveRecord::Base.while_preventing_writes do
+      assert_raises(ActiveRecord::ReadOnlyError) do
+        person.with_lock(CUSTOM_LOCK) do
+        end
+      end
+    end
+  end
+
+  def test_relation_lock_when_not_preventing_writes
+    assert_nothing_raised do
+      Person.lock.find_by id: 1
+    end
+  end
+
+  def test_relation_lock_when_preventing_writes
+    ActiveRecord::Base.while_preventing_writes do
+      assert_raises(ActiveRecord::ReadOnlyError) do
+        Person.lock.find_by id: 1
+      end
+    end
+  end
+
+  def test_relation_lock_when_not_preventing_writes_nested
+    ActiveRecord::Base.while_preventing_writes do
+      ActiveRecord::Base.while_preventing_writes(false) do
+        assert_nothing_raised do
+          Person.lock.find_by id: 1
+        end
+      end
+    end
+  end
+
+  def test_custom_relation_lock_when_preventing_writes
+    ActiveRecord::Base.while_preventing_writes do
+      assert_raises(ActiveRecord::ReadOnlyError) do
+        Person.lock(CUSTOM_LOCK).find_by id: 1
+      end
+    end
+  end
+end
