@@ -15,9 +15,9 @@ class ActiveRecord::Relation
     end
 
     test "+ is associative, but not commutative" do
-      a = WhereClause.new(["a"])
-      b = WhereClause.new(["b"])
-      c = WhereClause.new(["c"])
+      a = WhereClause.new([Arel.sql("a")])
+      b = WhereClause.new([Arel.sql("b")])
+      c = WhereClause.new([Arel.sql("c")])
 
       assert_equal a + (b + c), (a + b) + c
       assert_not_equal a + b, b + a
@@ -103,7 +103,7 @@ class ActiveRecord::Relation
 
     test "a clause knows if it is empty" do
       assert_empty WhereClause.empty
-      assert_not_empty WhereClause.new(["anything"])
+      assert_not_empty WhereClause.new([Arel.sql("anything")])
     end
 
     test "invert cannot handle nil" do
@@ -126,7 +126,7 @@ class ActiveRecord::Relation
         table["id"].lteq(2),
         table["id"].is_not_distinct_from(1),
         table["id"].is_distinct_from(2),
-        "sql literal"
+        Arel.sql("sql literal"),
       ])
       expected = WhereClause.new([
         Arel::Nodes::Not.new(
@@ -141,7 +141,7 @@ class ActiveRecord::Relation
             table["id"].lteq(2),
             table["id"].is_not_distinct_from(1),
             table["id"].is_distinct_from(2),
-            Arel::Nodes::Grouping.new("sql literal")
+            Arel::Nodes::Grouping.new(Arel.sql("sql literal")),
           ])
         )
       ])
@@ -188,7 +188,7 @@ class ActiveRecord::Relation
       random_object = Object.new
       where_clause = WhereClause.new([
         table["id"].in([1, 2, 3]),
-        "foo = bar",
+        Arel.sql("foo = bar"),
         random_object,
       ])
       expected = Arel::Nodes::And.new([
@@ -202,7 +202,7 @@ class ActiveRecord::Relation
 
     test "ast removes any empty strings" do
       where_clause = WhereClause.new([table["id"].in([1, 2, 3])])
-      where_clause_with_empty = WhereClause.new([table["id"].in([1, 2, 3]), ""])
+      where_clause_with_empty = WhereClause.new([table["id"].in([1, 2, 3]), Arel.sql("")])
 
       assert_equal where_clause.ast, where_clause_with_empty.ast
     end
@@ -259,12 +259,12 @@ class ActiveRecord::Relation
     test "or will use only common conditions if one side only has common conditions" do
       only_common = WhereClause.new([
         table["id"].eq(bind_param(1)),
-        "foo = bar",
+        Arel.sql("foo = bar"),
       ])
 
       common_with_extra = WhereClause.new([
         table["id"].eq(bind_param(1)),
-        "foo = bar",
+        Arel.sql("foo = bar"),
         table["extra"].eq(bind_param("pluto")),
       ])
 
@@ -274,13 +274,13 @@ class ActiveRecord::Relation
 
     test "supports hash equality" do
       h = Hash.new(0)
-      h[WhereClause.new(["a"])] += 1
-      h[WhereClause.new(["a"])] += 1
-      h[WhereClause.new(["b"])] += 1
+      h[WhereClause.new([Arel.sql("a")])] += 1
+      h[WhereClause.new([Arel.sql("a")])] += 1
+      h[WhereClause.new([Arel.sql("b")])] += 1
 
       expected = {
-        WhereClause.new(["a"]) => 2,
-        WhereClause.new(["b"]) => 1
+        WhereClause.new([Arel.sql("a")]) => 2,
+        WhereClause.new([Arel.sql("b")]) => 1
       }
       assert_equal expected, h
     end
