@@ -198,6 +198,8 @@ class Author < ActiveRecord::Base
   belongs_to :author_address,       dependent: :destroy
   belongs_to :author_address_extra, dependent: :delete, class_name: "AuthorAddress"
 
+  belongs_to :published_author, class_name: "PublishedAuthor", foreign_key: :published_author_id, optional: true
+
   has_many :category_post_comments, through: :categories, source: :post_comments
 
   has_many :misc_posts, -> { where(posts: { title: ["misc post by bob", "misc post by mary"] }) }, class_name: "Post"
@@ -318,3 +320,8 @@ class AuthorFavoriteWithScope < ActiveRecord::Base
   belongs_to :author
   belongs_to :favorite_author, class_name: "Author"
 end
+
+class PublishedAuthor < ActiveRecord::Base
+  self.table_name = "authors"
+  has_many :books, class_name: "PublishedBook", foreign_key: :author_id
+end
