@@ -10,7 +10,8 @@ class ActiveStorage::Analyzer::AudioAnalyzerTest < ActiveSupport::TestCase
     blob = create_file_blob(filename: "audio.mp3", content_type: "audio/mp3")
     metadata = extract_metadata_from(blob)
 
-    assert_equal 0.914286, metadata[:duration]
+    assert (0.863379..0.914286).include?(metadata[:duration])
+
     assert_equal 128000, metadata[:bit_rate]
     assert_equal 44100, metadata[:sample_rate]
     assert_not_nil metadata[:tags]
