@@ -46,7 +46,6 @@ class HashExtTest < ActiveSupport::TestCase
     assert_respond_to h, :deep_stringify_keys!
     assert_respond_to h, :to_options
     assert_respond_to h, :to_options!
-    assert_respond_to h, :except
     assert_respond_to h, :except!
   end
 
@@ -401,10 +400,6 @@ class HashExtTest < ActiveSupport::TestCase
     original = { a: "x", b: "y", c: 10 }
     expected = { a: "x", b: "y" }
 
-    # Should return a new hash without the given keys.
-    assert_equal expected, original.except(:c)
-    assert_not_equal expected, original
-
     # Should replace the hash without the given keys.
     assert_equal expected, original.except!(:c)
     assert_equal expected, original
@@ -414,8 +409,6 @@ class HashExtTest < ActiveSupport::TestCase
     original = { a: "x", b: "y", c: 10 }
     expected = { a: "x" }
 
-    assert_equal expected, original.except(:b, :c)
-
     assert_equal expected, original.except!(:b, :c)
     assert_equal expected, original
   end
@@ -423,17 +416,8 @@ class HashExtTest < ActiveSupport::TestCase
   def test_except_with_original_frozen
     original = { a: "x", b: "y" }
     original.freeze
-    assert_nothing_raised { original.except(:a) }
-
     assert_raise(FrozenError) { original.except!(:a) }
   end
-
-  def test_except_does_not_delete_values_in_original
-    original = { a: "x", b: "y" }
-    assert_not_called(original, :delete) do
-      original.except(:a)
-    end
-  end
 end
 
 class IWriteMyOwnXML
@@ -584,19 +568,6 @@ class HashToXmlTest < ActiveSupport::TestCase
     assert_includes xml, %(<addresses type="array"><address><streets type="array"><street><name>)
   end
 
-  def test_timezoned_attributes
-    # TODO: Remove assertion in Rails 7.1 and add ActiveSupport::TimeWithZone to XML type mapping
-    assert_deprecated("ActiveSupport::TimeWithZone.name has been deprecated") do
-      xml = {
-        created_at: Time.utc(1999, 2, 2),
-        local_created_at: Time.utc(1999, 2, 2).in_time_zone("Eastern Time (US & Canada)")
-      }.to_xml(@xml_options)
-
-      assert_match %r{<created-at type="dateTime">1999-02-02T00:00:00Z</created-at>}, xml
-      assert_match %r{<local-created-at type="dateTime">1999-02-01T19:00:00-05:00</local-created-at>}, xml
-    end
-  end
-
   def test_multiple_records_from_xml_with_attributes_other_than_type_ignores_them_without_exploding
     topics_xml = <<-EOT
       <topics type="array" page="1" page-count="1000" per-page="2">
