@@ -56,6 +56,16 @@ Event = Struct.new(:case) do
   delegate :foo, to: :case
 end
 
+class BasicEvent < BasicObject
+  delegate :foo, to: :case
+
+  attr_reader :case
+
+  def initialize(kase)
+    @case = kase
+  end
+end
+
 Tester = Struct.new(:client) do
   delegate :name, to: :client, prefix: false
 
@@ -76,7 +86,7 @@ Product = Struct.new(:name) do
 end
 
 module ExtraMissing
-  def method_missing(sym, *args)
+  def method_missing(sym, ...)
     if sym == :extra_missing
       42
     else
@@ -141,6 +151,16 @@ class Cavern
   end
 end
 
+class BasicCavern < BasicObject
+  delegate_missing_to :target
+
+  attr_reader :target
+
+  def initialize(target)
+    @target = target
+  end
+end
+
 class Block
   def hello?
     true
@@ -492,6 +512,22 @@ class ModuleTest < ActiveSupport::TestCase
     assert_nil deserialized_array[1]
   end
 
+  def test_delegate_to_missing_raises_delegation_error_on_basic_object
+    cavern = BasicCavern.new(nil)
+
+    assert_raises(Module::DelegationError) do
+      cavern.some_method
+    end
+  end
+
+  def test_delegate_raises_delegation_error_on_basic_object
+    cavern = BasicEvent.new(nil)
+
+    assert_raises(Module::DelegationError) do
+      cavern.foo
+    end
+  end
+
   def test_delegate_with_case
     event = Event.new(Tester.new)
     assert_equal 1, event.foo
@@ -602,7 +638,34 @@ class ModuleTest < ActiveSupport::TestCase
       location.delegate(:street, :city, to: :@place, prefix: :the, private: true)
   end
 
-  def test_delegation_arity
+  def test_module_nesting_is_empty
+    # Ensure constant resolution is done from top level namespace and not ActiveSupport
+    require "json"
+    c = Class.new do
+      singleton_class.delegate :parse, to: ::JSON
+    end
+    assert_equal [1], c.parse("[1]")
+  end
+
+  def test_delegation_unreacheable_module
+    anonymous_class = Class.new
+    error = assert_raises ArgumentError do
+      Class.new do
+        delegate :something, to: anonymous_class
+      end
+    end
+    assert_includes error.message, "Can't delegate to anonymous class or module"
+
+    anonymous_class.singleton_class.define_method(:name) { "FakeName" }
+    error = assert_raises ArgumentError do
+      Class.new do
+        delegate :something, to: anonymous_class
+      end
+    end
+    assert_includes error.message, "Can't delegate to detached class or module: FakeName"
+  end
+
+  def test_delegation_arity_to_module
     c = Class.new do
       delegate :zero, :one, :two, to: ArityTester
     end
@@ -610,6 +673,17 @@ class ModuleTest < ActiveSupport::TestCase
     assert_equal 1, c.instance_method(:one).arity
     assert_equal 2, c.instance_method(:two).arity
 
+    e = Class.new do
+      delegate :zero, to: ArityTesterModule
+    end
+
+    assert_equal 0, e.instance_method(:zero).arity
+    assert_nothing_raised do
+      e.new.zero
+    end
+  end
+
+  def test_delegation_arity_to_self_class
     d = Class.new(ArityTester) do
       delegate :zero, :zero_with_block, :zero_with_implicit_block, :one, :one_with_block, :two, :opt,
         :kwargs, :kwargs_with_block, :opt_kwargs, :opt_kwargs_with_block, to: :class
@@ -639,14 +713,5 @@ class ModuleTest < ActiveSupport::TestCase
       d.new.opt_kwargs(a: 1)
       d.new.opt_kwargs_with_block(a: 1, b: 2, c: 3)
     end
-
-    e = Class.new do
-      delegate :zero, to: ArityTesterModule
-    end
-
-    assert_equal 0, e.instance_method(:zero).arity
-    assert_nothing_raised do
-      e.new.zero
-    end
   end
 end
