@@ -26,6 +26,7 @@ class LoggerTest < ActiveSupport::TestCase
 
     assert_not Logger.logger_outputs_to?(@logger, STDOUT),         "Expected logger_outputs_to? to STDOUT to return false, but was true"
     assert_not Logger.logger_outputs_to?(@logger, STDOUT, STDERR), "Expected logger_outputs_to? to STDOUT or STDERR to return false, but was true"
+    assert_not Logger.logger_outputs_to?(@logger, "log/production.log")
   end
 
   def test_log_outputs_to_with_a_broadcast_logger
@@ -38,6 +39,20 @@ class LoggerTest < ActiveSupport::TestCase
     assert(Logger.logger_outputs_to?(logger, STDERR))
   end
 
+  def test_log_outputs_to_with_a_filename
+    t = Tempfile.new ["development", "log"]
+    logger = ActiveSupport::BroadcastLogger.new(Logger.new(t.path))
+
+    assert Logger.logger_outputs_to?(logger, t)
+    assert Logger.logger_outputs_to?(logger, t.path)
+    assert Logger.logger_outputs_to?(logger, File.join(File.dirname(t.path), ".", File.basename(t.path)))
+    assert_not Logger.logger_outputs_to?(logger, "log/production.log")
+    assert_not Logger.logger_outputs_to?(logger, STDOUT)
+  ensure
+    logger.close
+    t.close true
+  end
+
   def test_write_binary_data_to_existing_file
     t = Tempfile.new ["development", "log"]
     t.binmode
@@ -367,6 +382,37 @@ class LoggerTest < ActiveSupport::TestCase
     ActiveSupport::IsolatedExecutionState.isolation_level = previous_isolation_level
   end
 
+  def test_logger_freeze
+    logger = @logger.clone
+    logger.freeze
+
+    assert_nothing_raised do
+      assert_equal Logger::DEBUG, logger.level
+
+      logger.debug "I am frozen 1"
+      assert_includes @output.string, "I am frozen 1"
+
+      logger.debug { "I am frozen 2" }
+      assert_includes @output.string, "I am frozen 2"
+
+      logger.add Logger::INFO, "I am frozen 3"
+      assert_includes @output.string, "I am frozen 3"
+
+      logger.silence do
+        logger.debug "I am frozen 4"
+      end
+      assert_not_includes @output.string, "I am frozen 4"
+    end
+
+    assert_raises FrozenError do
+      logger.level = Logger::INFO
+    end
+
+    assert_raises FrozenError do
+      logger.formatter = Logger::Formatter.new
+    end
+  end
+
   def test_temporarily_logging_at_a_noisier_level
     @logger.level = Logger::INFO
 
