@@ -8,9 +8,22 @@ gemfile(true) do
   gem "rails"
   # If you want to test against edge Rails replace the previous line with this:
   # gem "rails", github: "rails/rails", branch: "main"
+  gem "net-smtp", github: "ruby/net-smtp", ref: "d496a829f9b99adb44ecc1768c4d005e5f7b779e", require: false
 end
 
 require "action_mailer/railtie"
+require "minitest/autorun"
+
+class TestApp < Rails::Application
+  config.load_defaults Rails::VERSION::STRING.to_f
+  config.root = __dir__
+  config.eager_load = false
+  config.hosts << "example.org"
+  config.secret_key_base = "secret_key_base"
+
+  config.logger = Logger.new($stdout)
+end
+Rails.application.initialize!
 
 class TestMailer < ActionMailer::Base
   def hello_world
@@ -23,8 +36,6 @@ class TestMailer < ActionMailer::Base
   end
 end
 
-require "minitest/autorun"
-
 class BugTest < ActionMailer::TestCase
   test "renders HTML and Text body" do
     email = TestMailer.hello_world
