@@ -75,14 +75,12 @@ DEFAULT_APP_FILES = %w(
   public/robots.txt
   script/.keep
   storage/.keep
-  test/application_system_test_case.rb
   test/controllers/.keep
   test/fixtures/files/.keep
   test/helpers/.keep
   test/integration/.keep
   test/mailers/.keep
   test/models/.keep
-  test/system/.keep
   test/test_helper.rb
   tmp/.keep
   tmp/pids/.keep
@@ -1384,13 +1382,6 @@ class AppGeneratorTest < Rails::Generators::TestCase
     assert_no_file "bin/docker-entrypoint"
   end
 
-  def test_system_tests_directory_generated
-    run_generator
-
-    assert_directory("test/system")
-    assert_file("test/system/.keep")
-  end
-
   unless Gem.win_platform?
     def test_master_key_is_only_readable_by_the_owner
       run_generator
@@ -1491,7 +1482,7 @@ class AppGeneratorTest < Rails::Generators::TestCase
           "context" => "..",
           "dockerfile" => ".devcontainer/Dockerfile"
         },
-        "volumes" => ["../../#{compose_config["name"]}:/workspaces/#{compose_config["name"]}:cached"],
+        "volumes" => ["../../tmp:/workspaces/tmp:cached"],
         "command" => "sleep infinity",
         "depends_on" => ["selenium"]
       }
@@ -1771,6 +1762,17 @@ class AppGeneratorTest < Rails::Generators::TestCase
     assert_no_file(".devcontainer/compose.yaml")
   end
 
+  def test_generated_yml_files_format
+    generator [destination_root]
+    run_generator_instance
+
+    Dir["**/*.yml"].each do |yml_file|
+      assert_file yml_file do |content|
+        assert_no_match(/\n\n\n/, content, "File `#{yml_file}` should not have double empty lines")
+      end
+    end
+  end
+
   private
     def assert_load_defaults
       assert_file "config/application.rb", /\s+config\.load_defaults #{Rails::VERSION::STRING.to_f}/
