@@ -8,21 +8,29 @@ class AuthenticationGeneratorTest < Rails::Generators::TestCase
   include GeneratorsTestHelper
 
   def setup
-    Rails.application = TestApp::Application
-    Rails.application.config.root = Pathname(destination_root)
+    FileUtils.mkdir_p("#{destination_root}/app/controllers")
+    File.write("#{destination_root}/app/controllers/application_controller.rb", <<~RUBY)
+      class ApplicationController < ActionController::Base
+      end
+    RUBY
+    FileUtils.mkdir_p("#{destination_root}/test")
+    File.write("#{destination_root}/test/test_helper.rb", <<~RUBY)
+      require "rails/test_help"
+      module ActiveSupport
+        class TestCase
+        end
+      end
+    RUBY
 
-    self.class.tests Rails::Generators::AppGenerator
-    run_generator([destination_root, "--no-skip-bundle"])
+    copy_gemfile
 
-    self.class.tests Rails::Generators::AuthenticationGenerator
-  end
-
-  def teardown
-    Rails.application = Rails.application.instance
+    copy_routes
   end
 
   def test_authentication_generator
-    run_generator
+    generator([destination_root])
+
+    run_generator_instance
 
     assert_file "app/models/user.rb"
     assert_file "app/models/current.rb"
@@ -47,20 +55,26 @@ class AuthenticationGeneratorTest < Rails::Generators::TestCase
       assert_match(/resource :session/, content)
     end
 
-    assert_migration "db/migrate/create_sessions.rb" do |content|
-      assert_match(/t.references :user, null: false, foreign_key: true/, content)
-    end
-
-    assert_migration "db/migrate/create_users.rb" do |content|
-      assert_match(/t.string :password_digest, null: false/, content)
-    end
+    assert_includes @rails_commands, "generate migration CreateUsers email_address:string!:uniq password_digest:string! --force"
+    assert_includes @rails_commands, "generate migration CreateSessions user:references ip_address:string user_agent:string --force"
 
     assert_file "test/models/user_test.rb"
     assert_file "test/fixtures/users.yml"
+    assert_file "test/controllers/sessions_controller_test.rb"
+    assert_file "test/controllers/passwords_controller_test.rb"
+    assert_file "test/mailers/previews/passwords_mailer_preview.rb"
+
+    assert_file "test/test_helpers/session_test_helper.rb"
+
+    assert_file "test/test_helper.rb" do |content|
+      assert_match("require_relative \"test_helpers/session_test_helper\"", content)
+    end
   end
 
   def test_authentication_generator_without_bcrypt_in_gemfile
-    File.write("Gemfile", File.read("Gemfile").sub(/# gem "bcrypt".*\n/, ""))
+    File.write("#{destination_root}/Gemfile", File.read("#{destination_root}/Gemfile").sub(/# gem "bcrypt".*\n/, ""))
+
+    generator([destination_root])
 
     run_generator_instance
 
@@ -68,7 +82,9 @@ class AuthenticationGeneratorTest < Rails::Generators::TestCase
   end
 
   def test_authentication_generator_with_api_flag
-    run_generator(["--api"])
+    generator([destination_root], api: true)
+
+    run_generator_instance
 
     assert_file "app/models/user.rb"
     assert_file "app/models/current.rb"
@@ -92,20 +108,25 @@ class AuthenticationGeneratorTest < Rails::Generators::TestCase
       assert_match(/resource :session/, content)
     end
 
-    assert_migration "db/migrate/create_sessions.rb" do |content|
-      assert_match(/t.references :user, null: false, foreign_key: true/, content)
-    end
-
-    assert_migration "db/migrate/create_users.rb" do |content|
-      assert_match(/t.string :password_digest, null: false/, content)
-    end
+    assert_includes @rails_commands, "generate migration CreateUsers email_address:string!:uniq password_digest:string! --force"
+    assert_includes @rails_commands, "generate migration CreateSessions user:references ip_address:string user_agent:string --force"
 
     assert_file "test/models/user_test.rb"
     assert_file "test/fixtures/users.yml"
+    assert_file "test/mailers/previews/passwords_mailer_preview.rb"
+
+    assert_file "test/test_helpers/session_test_helper.rb"
+
+    assert_file "test/test_helper.rb" do |content|
+      assert_match("require_relative \"test_helpers/session_test_helper\"", content)
+    end
   end
 
   def test_model_test_is_skipped_if_test_framework_is_given
-    content = run_generator ["authentication", "-t", "rspec"]
+    generator([destination_root], ["-t", "rspec"])
+
+    content = run_generator_instance
+
     assert_match(/rspec \[not found\]/, content)
     assert_no_file "test/models/user_test.rb"
   end
@@ -118,6 +139,18 @@ class AuthenticationGeneratorTest < Rails::Generators::TestCase
     assert_no_file "test/mailers/previews/passwords_mailer_preview.rb"
   end
 
+  def session_test_helper_is_skipped_if_test_framework_is_given
+    generator([destination_root], ["-t", "rspec"])
+
+    run_generator_instance
+
+    assert_no_file "test/test_helpers/session_test_helper.rb"
+    assert_file "test/test_helper.rb" do |test_helper_content|
+      assert_no_match(/session_test_helper/, test_helper_content)
+      assert_no_match(/SessionTestHelper/, test_helper_content)
+    end
+  end
+
   def test_connection_class_skipped_without_action_cable
     old_value = ActionCable.const_get(:Engine)
     ActionCable.send(:remove_const, :Engine)
@@ -129,6 +162,26 @@ class AuthenticationGeneratorTest < Rails::Generators::TestCase
     ActionCable.const_set(:Engine, old_value)
   end
 
+  def test_authentication_generator_without_action_mailer
+    old_value = ActionMailer.const_get(:Railtie)
+    ActionMailer.send(:remove_const, :Railtie)
+    generator([destination_root])
+    run_generator_instance
+
+    assert_no_file "app/mailers/application_mailer.rb"
+    assert_no_file "app/mailers/passwords_mailer.rb"
+    assert_no_file "app/views/passwords_mailer/reset.html.erb"
+    assert_no_file "app/views/passwords_mailer/reset.text.erb"
+    assert_no_file "test/mailers/previews/passwords_mailer_preview.rb"
+
+    assert_file "app/controllers/passwords_controller.rb" do |content|
+      assert_no_match(/def create\n    end/, content)
+      assert_no_match(/rate_limit/, content)
+    end
+  ensure
+    ActionMailer.const_set(:Railtie, old_value)
+  end
+
   private
     def run_generator_instance
       @bundle_commands = []
