@@ -49,7 +49,7 @@ module Rails
       def test_app_name_option
         run_generator ["--app-name", "my-TestApp_name"]
 
-        test_common_config
+        test_common_config_with_folder("my-TestApp_name")
         assert_devcontainer_json_file do |devcontainer_json|
           assert_equal "my-TestApp_name", devcontainer_json["name"]
         end
@@ -59,6 +59,22 @@ module Rails
         end
       end
 
+      def test_app_folder_option
+        run_generator ["--app-name", "sample_app", "--app-folder", "my_folder"]
+
+        test_common_config_with_folder("my_folder")
+        assert_devcontainer_json_file do |devcontainer_json|
+          assert_equal "sample_app", devcontainer_json["name"]
+        end
+
+        assert_compose_file do |compose|
+          assert_equal "sample_app", compose["name"]
+          # Verify the volume mount uses app_folder, not app_name
+          expected_volume = "../../my_folder:/workspaces/my_folder:cached"
+          assert_equal expected_volume, compose["services"]["rails-app"]["volumes"].first
+        end
+      end
+
       def test_database_default_sqlite3
         run_generator
 
@@ -344,6 +360,10 @@ module Rails
 
       private
         def test_common_config
+          test_common_config_with_folder("rails_app")
+        end
+
+        def test_common_config_with_folder(folder_name)
           assert_file(".devcontainer/Dockerfile") do |dockerfile|
             assert_match(/ARG RUBY_VERSION=#{RUBY_VERSION}/, dockerfile)
             assert_match(/ENV BINDING="0.0.0.0"/, dockerfile)
@@ -360,7 +380,7 @@ module Rails
                 "context" => "..",
                 "dockerfile" => ".devcontainer/Dockerfile"
               },
-              "volumes" => ["../../#{compose["name"]}:/workspaces/#{compose["name"]}:cached"],
+              "volumes" => ["../../#{folder_name}:/workspaces/#{folder_name}:cached"],
               "command" => "sleep infinity"
             }
             actual_independent_config = compose["services"]["rails-app"].except("depends_on")
