@@ -120,7 +120,7 @@ class PluginTestRunnerTest < ActiveSupport::TestCase
 
     def run_test_command(arguments = "")
       Dir.chdir(plugin_path) do
-        switch_env("BUNDLE_GEMFILE", "") { `bin/test #{arguments}` }
+        Bundler.with_unbundled_env { `bin/test #{arguments}` }
       end
     end
 end
