@@ -12,6 +12,12 @@ class TestUnitReporterTest < ActiveSupport::TestCase
   setup do
     @output = StringIO.new
     @reporter = Rails::TestUnitReporter.new @output, output_inline: true
+    @old_app_root = Rails::TestUnitReporter.app_root
+    Rails::TestUnitReporter.app_root = File.expand_path("../../", __dir__)
+  end
+
+  teardown do
+    Rails::TestUnitReporter.app_root = @old_app_root
   end
 
   test "prints rerun snippet to run a single failed test" do
