@@ -11,7 +11,7 @@ require "active_support"
 require "active_support/test_case"
 
 ActiveSupport::TestCase.extend Rails::LineFiltering
-Rails::TestUnitReporter.app_root = COMPONENT_ROOT
+Rails::TestUnitReporter.app_root ||= COMPONENT_ROOT
 Rails::TestUnitReporter.executable = "bin/test"
 
 Rails::TestUnit::Runner.parse_options(ARGV)
